Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1)

Unified Diff: Source/platform/fonts/Character.h

Issue 1119663002: Making Unicode character names consistent (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Rebase patch Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/modules/indexeddb/IDBKeyPath.cpp ('k') | Source/platform/fonts/Character.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/platform/fonts/Character.h
diff --git a/Source/platform/fonts/Character.h b/Source/platform/fonts/Character.h
index ca0666a6fcdf97ac4a7b1dd5499578b51858df96..b2a76fe5ceb69ebd3e487344597e32da0f04c486 100644
--- a/Source/platform/fonts/Character.h
+++ b/Source/platform/fonts/Character.h
@@ -61,26 +61,26 @@ public:
static bool treatAsSpace(UChar c)
{
- return c == space
- || c == characterTabulation
+ return c == spaceCharacter
+ || c == tabulationCharacter
|| c == newlineCharacter
- || c == noBreakSpace;
+ || c == noBreakSpaceCharacter;
}
static bool treatAsZeroWidthSpace(UChar c)
{
return treatAsZeroWidthSpaceInComplexScript(c)
- || c == zeroWidthNonJoiner
- || c == zeroWidthJoiner;
+ || c == zeroWidthNonJoinerCharacter
+ || c == zeroWidthJoinerCharacter;
}
static bool treatAsZeroWidthSpaceInComplexScript(UChar c)
{
return c < 0x20 // ASCII Control Characters
- || (c >= 0x7F && c < 0xA0) // ASCII Delete .. No-break space
- || c == softHyphen
- || c == zeroWidthSpace
- || (c >= leftToRightMark && c <= rightToLeftMark)
- || (c >= leftToRightEmbed && c <= rightToLeftOverride)
- || c == zeroWidthNoBreakSpace
+ || (c >= 0x7F && c < 0xA0) // ASCII Delete .. No-break spaceCharacter
+ || c == softHyphenCharacter
+ || c == zeroWidthSpaceCharacter
+ || (c >= leftToRightMarkCharacter && c <= rightToLeftMarkCharacter)
+ || (c >= leftToRightEmbedCharacter && c <= rightToLeftOverrideCharacter)
+ || c == zeroWidthNoBreakSpaceCharacter
|| c == objectReplacementCharacter;
}
static bool canReceiveTextEmphasis(UChar32);
@@ -88,10 +88,10 @@ public:
static inline UChar normalizeSpaces(UChar character)
{
if (treatAsSpace(character))
- return space;
+ return spaceCharacter;
if (treatAsZeroWidthSpace(character))
- return zeroWidthSpace;
+ return zeroWidthSpaceCharacter;
return character;
}
« no previous file with comments | « Source/modules/indexeddb/IDBKeyPath.cpp ('k') | Source/platform/fonts/Character.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698